# Put in a separate page so it can be used by SciMLDocs.jl

pages = [
    "Home" => "index.md",
    "samplers.md",
    "randomization.md",
    "design_matrix.md",
    "types.md"
]
